==> maleo_core-0.2.36.tar.gz: maleo_core-0.2.36/maleo_core/clients/maleo_suite/maleo_access/http/controllers/blood_type.py <==
from maleo_core.clients.maleo_suite.maleo_access.http.manager import MaleoAccessHTTPClientManager
from maleo_core.models.base.transfers.parameters.general import BaseGeneralParameters
from maleo_core.models.base.transfers.results.clients.http.controller import BaseHTTPClientControllerResults
from maleo_core.models.maleo_suite.maleo_access.transfers.parameters.client.blood_type import MaleoAccessBloodTypeClientParameters
from maleo_core.models.maleo_suite.maleo_access.transfers.parameters.general.blood_type import MaleoAccessBloodTypeGeneralParameters

class MaleoAccessBloodTypeHTTPController:
    @staticmethod
    async def get_blood_types(
        parameters:MaleoAccessBloodTypeClientParameters.Get
    ) -> BaseHTTPClientControllerResults:
        """Fetch blood types from maleo-access"""
        async with MaleoAccessHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoAccessHTTPClientManager._base_url}/v1/blood-types/"

            query_parameters = MaleoAccessBloodTypeClientParameters.GetQuery.model_validate(parameters.model_dump())
            params = query_parameters.to_query_params()

            #* Get Response
            response = await client.get(url=url, params=params)
            return BaseHTTPClientControllerResults(response=response)

    @staticmethod
    async def get_blood_type(
        parameters:MaleoAccessBloodTypeGeneralParameters.GetSingle
    ) -> BaseHTTPClientControllerResults:
        """Fetch blood type from maleo-access"""
        async with MaleoAccessHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoAccessHTTPClientManager._base_url}/v1/blood-types/"
            if parameters.identifier == MaleoAccessBloodTypeGeneralParameters.Identifiers.ID:
                url += f"{parameters.value}"
            else:
                url += f"{parameters.identifier.value}/{parameters.value}"

            #* Construct query parameters
            params = parameters.model_dump() if parameters else {}

            #* Get Response
            response = await client.get(url=url, params=params)
            return BaseHTTPClientControllerResults(response=response)

    @staticmethod
    async def status_update(
        blood_type_id:int,
        parameters:BaseGeneralParameters.StatusUpdate
    ) -> BaseHTTPClientControllerResults:
        """Update blood type's status"""
        async with MaleoAccessHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoAccessHTTPClientManager._base_url}/v1/blood-types/{blood_type_id}/status"

            #* Construct query parameters
            params = parameters.model_dump() if parameters else {}

            #* Get Response
            response = await client.get(url=url, params=params)
            return BaseHTTPClientControllerResults(response=response)

==> maleo_core-0.3.5.tar.gz: maleo_core-0.3.5/maleo_core/clients/maleo_suite/maleo_access/http/controllers/blood_type.py <==
from maleo_core.clients.maleo_suite.maleo_access.http.manager import MaleoAccessHTTPClientManager
from maleo_core.models.base.transfers.parameters.general import BaseGeneralParameters
from maleo_core.models.base.transfers.results.clients.http.controller import BaseHTTPClientControllerResults
from maleo_core.models.maleo_suite.maleo_access.transfers.parameters.client.blood_type import MaleoAccessBloodTypeClientParameters
from maleo_core.models.maleo_suite.maleo_access.transfers.parameters.general.blood_type import MaleoAccessBloodTypeGeneralParameters

class MaleoAccessBloodTypeHTTPController:
    @staticmethod
    async def get_blood_types(
        parameters:MaleoAccessBloodTypeClientParameters.Get
    ) -> BaseHTTPClientControllerResults:
        """Fetch blood types from maleo-access"""
        async with MaleoAccessHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoAccessHTTPClientManager._base_url}/v1/blood-types/"

            query_parameters = MaleoAccessBloodTypeClientParameters.GetQuery.model_validate(parameters.model_dump())
            params = query_parameters.to_query_params()

            #* Get Response
            response = await client.get(url=url, params=params)
            return BaseHTTPClientControllerResults(response=response)

    @staticmethod
    async def get_blood_type(
        parameters:MaleoAccessBloodTypeGeneralParameters.GetSingle
    ) -> BaseHTTPClientControllerResults:
        """Fetch blood type from maleo-access"""
        async with MaleoAccessHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoAccessHTTPClientManager._base_url}/v1/blood-types/"
            if parameters.identifier == MaleoAccessBloodTypeGeneralParameters.UniqueIdentifiers.ID:
                url += f"{parameters.value}"
            else:
                url += f"{parameters.identifier.value}/{parameters.value}"

            #* Construct query parameters
            query_params = BaseGeneralParameters.GetSingleQuery.model_validate(parameters.model_dump())
            params = query_params.model_dump()

            #* Get Response
            response = await client.get(url=url, params=params)
            return BaseHTTPClientControllerResults(response=response)

    @staticmethod
    async def create(parameters:MaleoAccessBloodTypeGeneralParameters.CreateOrUpdate) -> BaseHTTPClientControllerResults:
        """Create new blood type"""
        async with MaleoAccessHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoAccessHTTPClientManager._base_url}/v1/blood-types/"

            #* Define headers
            headers = {
                "Content-Type": "application/json"
            }

            #* Construct body
            json = parameters.model_dump()

            #* Get Response
            response = await client.post(url=url, json=json, headers=headers)
            return BaseHTTPClientControllerResults(response=response)

    @staticmethod
    async def update(
        blood_type_id:int,
        parameters:MaleoAccessBloodTypeGeneralParameters.CreateOrUpdate
    ) -> BaseHTTPClientControllerResults:
        """Update blood type's data"""
        async with MaleoAccessHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoAccessHTTPClientManager._base_url}/v1/blood-types/{blood_type_id}"

            #* Define headers
            headers = {
                "Content-Type": "application/json"
            }

            #* Construct body
            json = parameters.model_dump()

            #* Get Response
            response = await client.put(url=url, json=json, headers=headers)
            return BaseHTTPClientControllerResults(response=response)

    @staticmethod
    async def status_update(
        blood_type_id:int,
        parameters:BaseGeneralParameters.StatusUpdate
    ) -> BaseHTTPClientControllerResults:
        """Update blood type's status"""
        async with MaleoAccessHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoAccessHTTPClientManager._base_url}/v1/blood-types/{blood_type_id}/status"

            #* Construct query parameters
            params = parameters.model_dump() if parameters else {}

            #* Get Response
            response = await client.patch(url=url, params=params)
            return BaseHTTPClientControllerResults(response=response)
